@@ -1,19 +1,18 @@
-from typing import Optional, Union
-
-from pydantic import validator
+from typing import Union
 
 from aqueduct_executor.operators.connectors.tabular import common, models
+from pydantic import validator
 
 
 class RelationalParams(models.BaseParams):
     table: str
-    update_mode: Optional[common.UpdateMode] = common.UpdateMode.REPLACE
+    update_mode: common.UpdateMode = common.UpdateMode.REPLACE
 
     class Config:
         validate_assignment = True
 
     @validator("update_mode")
-    def set_update_mode(cls, update_mode):
+    def set_update_mode(cls, update_mode):  # type: ignore
         if update_mode == "":
             return common.UpdateMode.REPLACE
         return update_mode
