@@ -1,11 +1,12 @@
 import json
+
 from pydantic import BaseModel, parse_obj_as
 
 try:
     from typing import Literal
 except ImportError:
     # Python 3.7 does not support typing.Literal
-    from typing_extensions import Literal
+    from typing_extensions import Literal  # type: ignore
 
 from aqueduct_executor.operators.utils import enums
 from aqueduct_executor.operators.utils.storage import config
@@ -21,7 +22,7 @@ class ParamSpec(BaseModel):
     output_metadata_path: str
 
 
-def parse_spec(spec_json: str) -> ParamSpec:
+def parse_spec(spec_json: bytes) -> ParamSpec:
     """
     Parses a JSON string into a FunctionSpec.
     """
